@@ -1,16 +1,16 @@
 from __future__ import annotations
 
+from .config import setup
 from .convert import DefaultConverter
 from .fields import ForeignKey, Related
-from .opts import setup
 from .schema import ModelSchema
 
 __all__ = (
-    "ModelSchema",
     "DefaultConverter",
-    "Timestamp",
-    "MSTimestamp",
-    "Related",
     "ForeignKey",
+    "MSTimestamp",
+    "ModelSchema",
+    "Related",
+    "Timestamp",
     "setup",
 )
